@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,9 +29,11 @@
 #include "guiconfig.h"
 
 #ifdef Q_OS_WIN
+#ifdef AVOID_SCREENSAVER
 /* Disable screensaver by event */
 #include <windows.h>
 #endif
+#endif
 
 //#define SHARE_MENU
 
@@ -60,13 +62,16 @@ class Favorites;
 class TVList;
 class UpdateChecker;
 
+#ifdef SHAREWIDGET
+class ShareWidget;
+#endif
 
 class BaseGui : public QMainWindow
 {
     Q_OBJECT
     
 public:
-    BaseGui( QWidget* parent = 0, Qt::WindowFlags flags = 0 );
+	BaseGui( QWidget* parent = 0, Qt::WindowFlags flags = 0 );
 	~BaseGui();
 
 	/* Return true if the window shouldn't show on startup */
@@ -85,6 +90,9 @@ public:
 	void recordSmplayerLog(QString line);
 #endif
 
+	Core * getCore() { return core; };
+	Playlist * getPlaylist() { return playlist; };
+
 public slots:
 	virtual void open(QString file); // Generic open, autodetect type.
 	virtual void openFile();
@@ -156,6 +164,7 @@ public slots:
 	virtual void showGotoDialog();
 	virtual void showSubDelayDialog();
 	virtual void showAudioDelayDialog();
+	virtual void showStereo3dDialog();
 
 	virtual void exitFullscreen();
 	virtual void toggleFullscreen();
@@ -215,21 +224,18 @@ protected slots:
 	void displayWarningAboutOldMplayer();
 #endif
 
-#ifdef UPDATE_CHECKER
-	void reportNewVersionAvailable(QString);
-#endif
-
 #ifdef CHECK_UPGRADED
 	void checkIfUpgraded();
 #endif
 
-#ifdef REMINDER_ACTIONS
+#if defined(REMINDER_ACTIONS) && !defined(SHAREWIDGET)
 	void checkReminder();
 #endif
 
 #ifdef YOUTUBE_SUPPORT
+	void YTNoSslSupport();
 	void YTNoSignature(const QString &);
-	#ifdef YT_USE_SCRIPT
+	#ifdef YT_USE_YTSIG
 	void YTUpdateScript();
 	#endif
 #endif
@@ -238,8 +244,8 @@ protected slots:
 #if AUTODISABLE_ACTIONS
 	virtual void enableActionsOnPlaying();
 	virtual void disableActionsOnStop();
-	virtual void togglePlayAction(Core::State);
 #endif
+	virtual void togglePlayAction(Core::State);
 
 	void changeSizeFactor(int factor);
 	void toggleDoubleSize();
@@ -295,14 +301,16 @@ protected slots:
 
 	// stylesheet
 #if ALLOW_CHANGE_STYLESHEET
-	virtual void loadQss(QString filename);
+	virtual QString loadQss(QString filename);
 	virtual void changeStyleSheet(QString style);
 #endif
 
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+#ifdef AVOID_SCREENSAVER
 	/* Disable screensaver by event */
 	void clear_just_stopped();
 #endif
+#endif
 
 #ifdef LOG_MPLAYER
 	//! Clears the mplayer log
@@ -344,8 +352,13 @@ signals:
 protected:
 	virtual void retranslateStrings();
 	virtual void changeEvent(QEvent * event);
+#if QT_VERSION < 0x050000
 	virtual void hideEvent( QHideEvent * );
 	virtual void showEvent( QShowEvent * );
+#else
+	virtual bool event(QEvent * e);
+	bool was_minimized;
+#endif
 #ifdef Q_OS_WIN
 	#ifdef AVOID_SCREENSAVER
 	/* Disable screensaver by event */
@@ -376,6 +389,7 @@ protected:
 	void createMenus();
 	void updateRecents();
 	void configureDiscDevices();
+	void setupNetworkProxy();
 	/* virtual void closeEvent( QCloseEvent * e ); */
 
 protected:
@@ -407,6 +421,7 @@ protected:
 	MyAction * pauseAndStepAct;
 	MyAction * stopAct;
 	MyAction * frameStepAct;
+	MyAction * frameBackStepAct;
 	MyAction * rewind1Act;
 	MyAction * rewind2Act;
 	MyAction * rewind3Act;
@@ -441,6 +456,7 @@ protected:
 #endif
 	MyAction * flipAct;
 	MyAction * mirrorAct;
+	MyAction * stereo3dAct;
 	MyAction * postProcessingAct;
 	MyAction * phaseAct;
 	MyAction * deblockAct;
@@ -476,7 +492,7 @@ protected:
 	MyAction * decSubStepAct;
 	MyAction * incSubScaleAct;
 	MyAction * decSubScaleAct;
-	MyAction * useAssAct;
+	MyAction * useCustomSubStyleAct;
 	MyAction * useForcedSubsOnlyAct;
 	MyAction * subVisibilityAct;
 #ifdef FIND_SUBTITLES
@@ -503,7 +519,7 @@ protected:
 	MyAction * showFAQAct;
 	MyAction * showCLOptionsAct; // Command line options
 	MyAction * showCheckUpdatesAct;
-#if defined(YOUTUBE_SUPPORT) && defined(YT_USE_SCRIPT)
+#if defined(YOUTUBE_SUPPORT) && defined(YT_USE_YTSIG)
 	MyAction * updateYTAct;
 #endif
 	MyAction * showConfigAct;
@@ -520,6 +536,10 @@ protected:
 	MyAction * yahooAct;
 #endif
 
+	// OSD
+	MyAction * incOSDScaleAct;
+	MyAction * decOSDScaleAct;
+
 	// Playlist
 	MyAction * playPrevAct;
 	MyAction * playNextAct;
@@ -554,6 +574,7 @@ protected:
 	MyAction * nextWheelFunctionAct;
 
 	MyAction * showFilenameAct;
+	MyAction * showTimeAct;
 	MyAction * toggleDeinterlaceAct;
 
 	// Moving and zoom
@@ -568,10 +589,6 @@ protected:
 	MyAction * autoZoom169Act;
 	MyAction * autoZoom235Act;
 
-#if USE_MPLAYER_PANSCAN
-	MyAction * incPanscanAct;
-	MyAction * decPanscanAct;
-#endif
 
 	// OSD Action Group 
 	MyActionGroup * osdGroup;
@@ -691,6 +708,9 @@ protected:
 	MyActionGroup * videoTrackGroup;
 	MyActionGroup * audioTrackGroup;
 	MyActionGroup * subtitleTrackGroup;
+#ifdef MPV_SUPPORT
+	MyActionGroup * secondarySubtitleTrackGroup;
+#endif
 	MyActionGroup * titleGroup;
 	MyActionGroup * angleGroup;
 	MyActionGroup * chapterGroup;
@@ -717,7 +737,10 @@ protected:
 	QMenu *helpMenu;
 
 	QMenu * disc_menu;
-	QMenu * subtitlestrack_menu;
+	QMenu * subtitles_track_menu;
+#ifdef MPV_SUPPORT
+	QMenu * secondary_subtitles_track_menu;
+#endif
 #if PROGRAM_SWITCH
 	QMenu * programtrack_menu;
 #endif
@@ -790,6 +813,10 @@ protected:
 	UpdateChecker * update_checker;
 #endif
 
+#ifdef SHAREWIDGET
+	ShareWidget * sharewidget;
+#endif
+
 	QStringList actions_list;
 
 	QString pending_actions_to_run;
@@ -808,9 +835,11 @@ private:
 	bool was_maximized;
 
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+#ifdef AVOID_SCREENSAVER
 	/* Disable screensaver by event */
 	bool just_stopped;
 #endif
+#endif
 
 #ifdef LOG_MPLAYER
 	QString mplayer_log;
