@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,14 +23,15 @@
 #include <QProcess> // For QProcess::ProcessError
 #include "mediadata.h"
 #include "mediasettings.h"
-#include "mplayerprocess.h"
+#include "playerprocess.h"
+
 #include "config.h"
 
 #ifndef NO_USE_INI_FILES
 class FileSettingsBase;
 #endif
 
-class MplayerProcess;
+class PlayerProcess;
 class MplayerWindow;
 class QSettings;
 
@@ -51,10 +52,10 @@ class Core : public QObject
 public:
 	enum State { Stopped = 0, Playing = 1, Paused = 2 };
 
-    Core( MplayerWindow *mpw, QWidget* parent = 0 );
-    ~Core();
+	Core( MplayerWindow *mpw, QWidget* parent = 0 );
+	~Core();
 
-    MediaData mdat;
+	MediaData mdat;
 	MediaSettings mset;
 
 	//! Return the current state
@@ -64,6 +65,8 @@ public:
 	//! so it can be printed on debugging messages.
 	QString stateToString();
 
+	void addForcedTitle(const QString & file, const QString & title) { forced_titles[file] = title; };
+
 protected:
 	//! Change the current state (Stopped, Playing or Paused)
 	//! And sends the stateChanged() signal.
@@ -80,6 +83,9 @@ public slots:
 	void openDVD(int title = 1);
 	*/
 	void openDVD(QString dvd_url);
+#ifdef BLURAY_SUPPORT
+	void openBluRay(QString blu_ray_url);
+#endif
 	void openVCD(int title = -1);
 	void openAudioCD(int title = -1);
 	void openTV(QString channel_id);
@@ -104,6 +110,7 @@ public slots:
     void pause_and_frame_step();
 	void pause();
 	void frameStep();
+	void frameBackStep();
 	void screenshot();	//!< Take a screenshot of current frame
 	void screenshots();	//!< Start/stop taking screenshot of each frame
 
@@ -165,7 +172,9 @@ public slots:
 	void changeDenoise(int);
 	void changeUnsharp(int);
 	void changeLetterbox(bool);
+	void changeLetterboxOnFullscreen(bool);
 	void changeUpscale(bool);
+	void changeStereo3d(const QString & in, const QString & out);
 
 	void seek(int secs);
 	void sforward(); 	// + 10 seconds
@@ -228,6 +237,10 @@ public slots:
 	void incSubScale();
 	void decSubScale();
 
+	void changeOSDScale(double value);
+	void incOSDScale();
+	void decOSDScale();
+
 	//! Select next line in subtitle file
 	void incSubStep();
 	//! Select previous line in subtitle file
@@ -242,6 +255,7 @@ public slots:
 	void setAudioAudioEqualizerRestart(AudioEqualizerList values) { setAudioEqualizer(values, true); };
 	void updateAudioEqualizer();
 
+	void setAudioEq(int eq, int value);
 	void setAudioEq0(int value);
 	void setAudioEq1(int value);
 	void setAudioEq2(int value);
@@ -254,8 +268,11 @@ public slots:
 	void setAudioEq9(int value);
 
 	void changeDeinterlace(int);
-    void changeSubtitle(int);
+	void changeSubtitle(int);
 	void nextSubtitle();
+#ifdef MPV_SUPPORT
+	void changeSecondarySubtitle(int);
+#endif
 	void changeAudio(int ID, bool allow_restart = true);
 	void nextAudio();
 	void changeVideo(int ID, bool allow_restart = true);
@@ -295,16 +312,11 @@ public slots:
 	void autoZoomFor169();
 	void autoZoomFor235();
 
-#if USE_MPLAYER_PANSCAN
-	void changePanscan(double);
-	void incPanscan();
-	void decPanscan();
-#endif
-
 	void showFilenameOnOSD();
+	void showTimeOnOSD();
 	void toggleDeinterlace();
 
-	void changeUseAss(bool);
+	void changeUseCustomSubStyle(bool);
 	void toggleForcedSubsOnly(bool);
 
 	void changeClosedCaptionChannel(int);
@@ -325,8 +337,8 @@ public slots:
 	void dvdnavMouse();
 #endif
 
-    // Pass a command to mplayer by stdin:
-    void tellmp(const QString & command);
+	//! Change fullscreen when using the player own window
+	void changeFullscreenMode(bool b);
 
 	//! Wrapper for the osd_show_text slave command
 	void displayTextOnOSD(QString text, int duration = 3000, int level = 1, 
@@ -336,6 +348,8 @@ public:
 	//! Returns the number of the first chapter in 
 	//! files. In some versions of mplayer is 0, in others 1
 	static int firstChapter();
+	int firstDVDTitle();
+	int firstBlurayTitle();
 
 #ifndef NO_USE_INI_FILES
 	void changeFileSettingsMethod(QString method);
@@ -344,7 +358,7 @@ public:
 protected:
 	//! Returns the prefix to keep pausing on slave commands
 	QString pausing_prefix();
-	QString seek_cmd(double secs, int mode);
+	void seek_cmd(double secs, int mode);
 
 protected slots:
     void changeCurrentSec(double sec);
@@ -354,6 +368,8 @@ protected slots:
 	void gotVO(QString);
 	void gotAO(QString);
 	void gotStartingTime(double);
+	void gotVideoBitrate(int);
+	void gotAudioBitrate(int);
 
 	void finishRestart();
     void processFinished();
@@ -363,6 +379,7 @@ protected slots:
 	void displayScreenshotName(QString filename);
 	void displayUpdatingFontCache();
 	void displayBuffering();
+	void displayPlaying();
 
 	void streamTitleChanged(QString);
 	void streamTitleAndUrlChanged(QString,QString);
@@ -383,10 +400,17 @@ protected slots:
 #if NOTIFY_AUDIO_CHANGES
 	void initAudioTrack(const Tracks &);
 #endif
+#if NOTIFY_VIDEO_CHANGES
+	void initVideoTrack(const Tracks &);
+#endif
 #if NOTIFY_SUB_CHANGES
 	void initSubtitleTrack(const SubTracks &);
 	void setSubtitleTrackAgain(const SubTracks &);
 #endif
+#if NOTIFY_CHAPTER_CHANGES
+	void updateChapterInfo(const Chapters &);
+#endif
+
 #if DVDNAV_SUPPORT
 	void dvdTitleChanged(int);
 	void durationChanged(double);
@@ -401,10 +425,16 @@ protected slots:
 #ifdef YOUTUBE_SUPPORT
 	void connectingToYT(QString host);
 	void YTFailed(int error_number, QString error_str);
-	/* void YTNoSignature(); */
 	void YTNoVideoUrl();
 #endif
 
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+#ifdef SCREENSAVER_OFF
+	void enableScreensaver();
+	void disableScreensaver();
+#endif
+#endif
+
 protected:
 	void playNewFile(QString file, int seek=-1);
 	void restartPlay();
@@ -424,6 +454,8 @@ protected:
 	//! Returns true if changing the subscale requires to restart mplayer
 	bool subscale_need_restart();
 
+	int adjustVolume(int v, int max_vol);
+
 signals:
 	void buffering();
 	void aboutToStartPlaying(); // Signal emited just before to start mplayer
@@ -431,7 +463,7 @@ signals:
 	void mediaInfoChanged();
 	//! Sends the filename and title of the stream playing in this moment
 	void mediaPlaying(const QString & filename, const QString & title);
-    void stateChanged(Core::State state);
+	void stateChanged(Core::State state);
 	void mediaStartPlay();
 	void mediaFinished(); // Media has arrived to the end.
 	void mediaStoppedByUser();
@@ -447,6 +479,7 @@ signals:
 #else
 	void posChanged(int); // To connect a slider
 #endif
+	void newDuration(double); // Duration has changed
 	void showFrame(int frame);
 	void ABMarkersChanged(int secs_a, int secs_b);
 	void needResize(int w, int h);
@@ -456,6 +489,9 @@ signals:
 	void audioTracksChanged();
 #endif
 
+	//! Sent when requested to play, but there is no file to play
+	void noFileToPlay();
+
 	//! MPlayer started but finished with exit code != 0
 	void mplayerFinishedWithError(int exitCode);
 
@@ -470,11 +506,14 @@ signals:
 
 #ifdef YOUTUBE_SUPPORT
 	void signatureNotFound(const QString &);
+	void noSslSupport();
 #endif
 
+	void receivedForbidden();
+
 protected:
-    MplayerProcess * proc;
-    MplayerWindow * mplayerwindow;
+	PlayerProcess * proc;
+	MplayerWindow * mplayerwindow;
 
 #ifndef NO_USE_INI_FILES
 	FileSettingsBase * file_settings;
@@ -490,7 +529,7 @@ protected:
 #ifdef YOUTUBE_SUPPORT
 	RetrieveYoutubeUrl * yt;
 #endif
-    
+
 private:
 	// Some variables to proper restart
 	bool we_are_restarting;
@@ -505,6 +544,8 @@ private:
 #if DVDNAV_SUPPORT
 	bool dvdnav_title_is_menu;
 #endif
+
+	QMap<QString,QString> forced_titles;
 };
-    
+
 #endif
