@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,8 +24,9 @@ FindSubtitlesConfigDialog::FindSubtitlesConfigDialog( QWidget* parent, Qt::Windo
 {
 	setupUi(this);
 
-	proxy_type_combo->addItem( tr("Http"), QNetworkProxy::HttpProxy);
-	proxy_type_combo->addItem( tr("Socks5"), QNetworkProxy::Socks5Proxy);
+#ifdef FS_USE_PROXY
+	proxy_type_combo->addItem( tr("HTTP"), QNetworkProxy::HttpProxy);
+	proxy_type_combo->addItem( tr("SOCKS5"), QNetworkProxy::Socks5Proxy);
 
 	use_proxy_check->setWhatsThis( tr("Enable/disable the use of the proxy.") );
 	proxy_hostname_edit->setWhatsThis( tr("The host name of the proxy.") );
@@ -35,6 +36,13 @@ FindSubtitlesConfigDialog::FindSubtitlesConfigDialog( QWidget* parent, Qt::Windo
         tr("The password for the proxy. <b>Warning:</b> the password will be saved "
            "as plain text in the configuration file.") );
 	proxy_type_combo->setWhatsThis( tr("Select the proxy type to be used.") );
+#else
+	proxy_group->hide();
+#endif
+
+#ifndef OS_SEARCH_WORKAROUND
+	misc_group->hide();
+#endif
 
 	layout()->setSizeConstraint(QLayout::SetFixedSize);
 }
@@ -50,6 +58,17 @@ QString FindSubtitlesConfigDialog::server() {
 	return server_edit->text();
 }
 
+#ifdef OS_SEARCH_WORKAROUND
+void FindSubtitlesConfigDialog::setRetries(int n) {
+	retries_spin->setValue(n);
+}
+
+int FindSubtitlesConfigDialog::retries() {
+	return retries_spin->value();
+}
+#endif
+
+#ifdef FS_USE_PROXY
 void FindSubtitlesConfigDialog::setUseProxy(bool b) {
 	use_proxy_check->setChecked(b);
 }
@@ -100,5 +119,6 @@ int FindSubtitlesConfigDialog::proxyType() {
 	int index = proxy_type_combo->currentIndex();
 	return proxy_type_combo->itemData(index).toInt();
 }
+#endif
 
 #include "moc_findsubtitlesconfigdialog.cpp"
