@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,9 +31,14 @@ MediaSettings::~MediaSettings() {
 }
 
 void MediaSettings::reset() {
+	qDebug("MediaSettings::reset");
+
 	current_sec = 0;
 	//current_sub_id = SubNone; 
 	current_sub_id = NoneSelected;
+#ifdef MPV_SUPPORT
+	current_secondary_sub_id = NoneSelected;
+#endif
 #if PROGRAM_SWITCH
 	current_program_id = NoneSelected;
 #endif
@@ -45,7 +50,7 @@ void MediaSettings::reset() {
 
 	aspect_ratio_id = AspectAuto;
 
-	//fullscreen = FALSE;
+	//fullscreen = false;
 	volume = pref->initial_volume;
 	mute = false;
 	external_subtitles = "";
@@ -79,6 +84,9 @@ void MediaSettings::reset() {
 	current_denoiser = NoDenoise;
 	current_unsharp = 0;
 
+	stereo3d_in = "none";
+	stereo3d_out = QString::null;
+
 	//current_deinterlacer = NoDeinterlace;
 	current_deinterlacer = pref->initial_deinterlace;
 
@@ -93,10 +101,6 @@ void MediaSettings::reset() {
 
 	zoom_factor = pref->initial_zoom_factor; // 1.0;
 
-#if USE_MPLAYER_PANSCAN
-	panscan_factor = 0;
-#endif
-
 	starting_time = -1; // Not set yet.
 
 	rotate = NoRotate;
@@ -109,13 +113,19 @@ void MediaSettings::reset() {
 
 	is264andHD = false;
 
+	current_demuxer = "unknown";
+
+#if ALLOW_DEMUXER_CODEC_CHANGE
 	forced_demuxer="";
-    forced_video_codec="";
-    forced_audio_codec="";
+	if (pref->use_lavf_demuxer) forced_demuxer = "lavf";
+
+	forced_video_codec="";
+	forced_audio_codec="";
 
 	original_demuxer="";
-    original_video_codec="";
-    original_audio_codec="";
+	original_video_codec="";
+	original_audio_codec="";
+#endif
 
 	mplayer_additional_options="";
 	mplayer_additional_video_filters="";
@@ -143,6 +153,7 @@ double MediaSettings::aspectToNum(Aspect aspect) {
 		case MediaSettings::Aspect11: asp = 1; break;
 		case MediaSettings::Aspect32: asp = (double) 3 / 2; break;
 		case MediaSettings::Aspect1410: asp = (double) 14 / 10; break;
+		case MediaSettings::Aspect118: asp = (double) 11 / 8; break;
 		case MediaSettings::AspectAuto: asp = win_aspect(); break;
 		default: asp = win_aspect(); 
                  qWarning("MediaSettings::aspectToNum: invalid aspect: %d", aspect);
@@ -165,6 +176,7 @@ QString MediaSettings::aspectToString(Aspect aspect) {
 		case MediaSettings::Aspect11: asp_name = "1:1"; break;
 		case MediaSettings::Aspect32: asp_name = "3:2"; break;
 		case MediaSettings::Aspect1410: asp_name = "14:10"; break;
+		case MediaSettings::Aspect118: asp_name = "11:8"; break;
 		case MediaSettings::AspectAuto: asp_name = QObject::tr("auto", "aspect_ratio"); break;
 		default: asp_name = QObject::tr("unknown", "aspect_ratio");
 	}
@@ -177,6 +189,9 @@ void MediaSettings::list() {
 
 	qDebug("  current_sec: %f", current_sec);
 	qDebug("  current_sub_id: %d", current_sub_id);
+#ifdef MPV_SUPPORT
+	qDebug("  current_secondary_sub_id: %d", current_secondary_sub_id);
+#endif
 #if PROGRAM_SWITCH
 	qDebug("  current_program_id: %d", current_program_id);
 #endif
@@ -219,6 +234,9 @@ void MediaSettings::list() {
 	qDebug("  current_denoiser: %d", current_denoiser);
 	qDebug("  current_unsharp: %d", current_unsharp);
 
+	qDebug("  stereo3d_in: %s", stereo3d_in.toUtf8().constData());
+	qDebug("  stereo3d_out: %s", stereo3d_out.toUtf8().constData());
+
 	qDebug("  current_deinterlacer: %d", current_deinterlacer);
 
 	qDebug("  add_letterbox: %d", add_letterbox);
@@ -232,10 +250,6 @@ void MediaSettings::list() {
 
 	qDebug("  zoom_factor: %f", zoom_factor);
 
-#if USE_MPLAYER_PANSCAN
-	qDebug("  panscan_factor: %f", zoom_factor);
-#endif
-
 	qDebug("  rotate: %d", rotate);
 	qDebug("  flip: %d", flip);
 	qDebug("  mirror: %d", mirror);
@@ -244,6 +258,9 @@ void MediaSettings::list() {
 	qDebug("  A_marker: %d", A_marker);
 	qDebug("  B_marker: %d", B_marker);
 
+	qDebug("  current_demuxer: '%s'", current_demuxer.toUtf8().data());
+
+#if ALLOW_DEMUXER_CODEC_CHANGE
 	qDebug("  forced_demuxer: '%s'", forced_demuxer.toUtf8().data());
 	qDebug("  forced_video_codec: '%s'", forced_video_codec.toUtf8().data());
 	qDebug("  forced_audio_codec: '%s'", forced_video_codec.toUtf8().data());
@@ -251,6 +268,7 @@ void MediaSettings::list() {
 	qDebug("  original_demuxer: '%s'", original_demuxer.toUtf8().data());
 	qDebug("  original_video_codec: '%s'", original_video_codec.toUtf8().data());
 	qDebug("  original_audio_codec: '%s'", original_video_codec.toUtf8().data());
+#endif
 
 	qDebug("  mplayer_additional_options: '%s'", mplayer_additional_options.toUtf8().data());
 	qDebug("  mplayer_additional_video_filters: '%s'", mplayer_additional_video_filters.toUtf8().data());
@@ -265,20 +283,46 @@ void MediaSettings::list() {
 }
 
 #ifndef NO_USE_INI_FILES
-void MediaSettings::save(QSettings * set) {
+void MediaSettings::save(QSettings * set, int player_id) {
 	qDebug("MediaSettings::save");
 
-	//QSettings * set = settings;
+	set->beginGroup("player_" + QString::number(player_id));
 
-	/*set->beginGroup( "mediasettings" );*/
-
-	set->setValue( "current_sec", current_sec );
-	set->setValue( "current_sub_id", current_sub_id );
-#if PROGRAM_SWITCH
-	set->setValue( "current_program_id", current_program_id );
+	set->setValue( "current_demuxer", current_demuxer);
+#if ALLOW_DEMUXER_CODEC_CHANGE
+	set->setValue( "forced_demuxer", forced_demuxer);
+	set->setValue( "forced_video_codec", forced_video_codec);
+	set->setValue( "forced_audio_codec", forced_audio_codec);
+	set->setValue( "original_demuxer", original_demuxer);
+	set->setValue( "original_video_codec", original_video_codec);
+	set->setValue( "original_audio_codec", original_audio_codec);
 #endif
+
+	// Save the tracks ID in a demuxer section
+	QString demuxer_section = QString("demuxer_%1").arg(current_demuxer);
+#if ALLOW_DEMUXER_CODEC_CHANGE
+	if (!forced_demuxer.isEmpty()) {
+		demuxer_section = QString("demuxer_%1").arg(forced_demuxer);
+	}
+#endif
+
+	set->beginGroup(demuxer_section);
+	set->setValue( "current_sub_id", current_sub_id );
+	#ifdef MPV_SUPPORT
+	set->setValue( "current_secondary_sub_id", current_secondary_sub_id );
+	#endif
+	#if PROGRAM_SWITCH
+	set->setValue( "current_program_id", current_program_id );
+	#endif
 	set->setValue( "current_video_id", current_video_id );
 	set->setValue( "current_audio_id", current_audio_id );
+	set->endGroup();
+
+	set->endGroup(); // player
+
+
+	set->setValue( "current_sec", current_sec );
+
 	set->setValue( "current_title_id", current_title_id );
 	set->setValue( "current_chapter_id", current_chapter_id );
 	set->setValue( "current_angle_id", current_angle_id );
@@ -318,6 +362,9 @@ void MediaSettings::save(QSettings * set) {
 	set->setValue( "current_denoiser", current_denoiser);
 	set->setValue( "current_unsharp", current_unsharp);
 
+	set->setValue( "stereo3d_in", stereo3d_in);
+	set->setValue( "stereo3d_out", stereo3d_out);
+
 	set->setValue( "current_deinterlacer", current_deinterlacer);
 
 	set->setValue( "add_letterbox", add_letterbox );
@@ -331,10 +378,6 @@ void MediaSettings::save(QSettings * set) {
 
 	set->setValue( "zoom_factor", zoom_factor);
 
-#if USE_MPLAYER_PANSCAN
-	set->setValue( "panscan_factor", zoom_factor);
-#endif
-
 	set->setValue( "rotate", rotate );
 	set->setValue( "flip", flip);
 	set->setValue( "mirror", mirror);
@@ -343,14 +386,6 @@ void MediaSettings::save(QSettings * set) {
 	set->setValue( "A_marker", A_marker);
 	set->setValue( "B_marker", B_marker);
 
-	set->setValue( "forced_demuxer", forced_demuxer);
-	set->setValue( "forced_video_codec", forced_video_codec);
-	set->setValue( "forced_audio_codec", forced_audio_codec);
-
-	set->setValue( "original_demuxer", original_demuxer);
-	set->setValue( "original_video_codec", original_video_codec);
-	set->setValue( "original_audio_codec", original_audio_codec);
-
 	set->setValue( "mplayer_additional_options", mplayer_additional_options);
 	set->setValue( "mplayer_additional_video_filters", mplayer_additional_video_filters);
 	set->setValue( "mplayer_additional_audio_filters", mplayer_additional_audio_filters);
@@ -361,24 +396,50 @@ void MediaSettings::save(QSettings * set) {
 	set->setValue( "starting_time", starting_time );
 
 	set->setValue( "is264andHD", is264andHD );
-
-	/*set->endGroup();*/
 }
 
-void MediaSettings::load(QSettings * set) {
+void MediaSettings::load(QSettings * set, int player_id) {
 	qDebug("MediaSettings::load");
 
-	//QSettings * set = settings;
+	set->beginGroup("player_" + QString::number(player_id));
+
+	current_demuxer = set->value( "current_demuxer", current_demuxer).toString();
+#if ALLOW_DEMUXER_CODEC_CHANGE
+	forced_demuxer = set->value( "forced_demuxer", forced_demuxer).toString();
+	if (pref->use_lavf_demuxer) forced_demuxer = "lavf";
+	forced_video_codec = set->value( "forced_video_codec", forced_video_codec).toString();
+	forced_audio_codec = set->value( "forced_audio_codec", forced_audio_codec).toString();
+	original_demuxer = set->value( "original_demuxer", original_demuxer).toString();
+	original_video_codec = set->value( "original_video_codec", original_video_codec).toString();
+	original_audio_codec = set->value( "original_audio_codec", original_audio_codec).toString();
+#endif
+
+	// Load the tracks ID from a demuxer section
+	QString demuxer_section = QString("demuxer_%1").arg(current_demuxer);
+#if ALLOW_DEMUXER_CODEC_CHANGE
+	if (!forced_demuxer.isEmpty()) {
+		demuxer_section = QString("demuxer_%1").arg(forced_demuxer);
+	}
+#endif
+	qDebug("MediaSettings::load: demuxer_section: %s", demuxer_section.toUtf8().constData());
+
+	set->beginGroup(demuxer_section);
+	current_sub_id = set->value( "current_sub_id", NoneSelected ).toInt();
+	#ifdef MPV_SUPPORT
+	current_secondary_sub_id = set->value( "current_secondary_sub_id", NoneSelected ).toInt();
+	#endif
+	#if PROGRAM_SWITCH
+	current_program_id = set->value( "current_program_id", NoneSelected ).toInt();
+	#endif
+	current_video_id = set->value( "current_video_id", NoneSelected ).toInt();
+	current_audio_id = set->value( "current_audio_id", NoneSelected ).toInt();
+	set->endGroup();
+
+	set->endGroup(); // player
 
-	/*set->beginGroup( "mediasettings" );*/
 
 	current_sec = set->value( "current_sec", current_sec).toDouble();
-	current_sub_id = set->value( "current_sub_id", current_sub_id ).toInt();
-#if PROGRAM_SWITCH
-	current_program_id = set->value( "current_program_id", current_program_id ).toInt();
-#endif
-	current_video_id = set->value( "current_video_id", current_video_id ).toInt();
-	current_audio_id = set->value( "current_audio_id", current_audio_id ).toInt();
+
 	current_title_id = set->value( "current_title_id", current_title_id ).toInt();
 	current_chapter_id = set->value( "current_chapter_id", current_chapter_id ).toInt();
 	current_angle_id = set->value( "current_angle_id", current_angle_id ).toInt();
@@ -418,6 +479,9 @@ void MediaSettings::load(QSettings * set) {
 	current_denoiser = set->value( "current_denoiser", current_denoiser).toInt();
 	current_unsharp = set->value( "current_unsharp", current_unsharp).toInt();
 
+	stereo3d_in = set->value( "stereo3d_in", stereo3d_in).toString();
+	stereo3d_out = set->value( "stereo3d_out", stereo3d_out).toString();
+
 	current_deinterlacer = set->value( "current_deinterlacer", current_deinterlacer ).toInt();
 
 	add_letterbox = set->value( "add_letterbox", add_letterbox ).toBool();
@@ -431,10 +495,6 @@ void MediaSettings::load(QSettings * set) {
 
 	zoom_factor = set->value( "zoom_factor", zoom_factor).toDouble();
 
-#if USE_MPLAYER_PANSCAN
-	panscan_factor = set->value( "panscan_factor", panscan_factor).toDouble();
-#endif
-
 	rotate = set->value( "rotate", rotate).toInt();
 	flip = set->value( "flip", flip).toBool();
 	mirror = set->value( "mirror", mirror).toBool();
@@ -443,13 +503,6 @@ void MediaSettings::load(QSettings * set) {
 	A_marker = set->value( "A_marker", A_marker).toInt();
 	B_marker = set->value( "B_marker", B_marker).toInt();
 
-	forced_demuxer = set->value( "forced_demuxer", forced_demuxer).toString();
-	forced_video_codec = set->value( "forced_video_codec", forced_video_codec).toString();
-	forced_audio_codec = set->value( "forced_audio_codec", forced_audio_codec).toString();
-
-	original_demuxer = set->value( "original_demuxer", original_demuxer).toString();
-	original_video_codec = set->value( "original_video_codec", original_video_codec).toString();
-	original_audio_codec = set->value( "original_audio_codec", original_audio_codec).toString();
 
 	mplayer_additional_options = set->value( "mplayer_additional_options", mplayer_additional_options).toString();
 	mplayer_additional_video_filters = set->value( "mplayer_additional_video_filters", mplayer_additional_video_filters).toString();
@@ -462,8 +515,6 @@ void MediaSettings::load(QSettings * set) {
 
 	is264andHD = set->value( "is264andHD", is264andHD ).toBool();
 
-	/*set->endGroup();*/
-
 	// ChDefault not used anymore
 	if (audio_use_channels == ChDefault) audio_use_channels = ChStereo;
 }
