@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,15 +30,23 @@ using namespace Global;
 
 #define TOO_CHAPTERS_WORKAROUND
 
-MplayerProcess::MplayerProcess(QObject * parent) : MyProcess(parent) 
-{
+MplayerProcess::MplayerProcess(QObject * parent)
+	: PlayerProcess(parent)
+	, notified_mplayer_is_running(false)
+	, received_end_of_file(false)
+	, last_sub_id(-1)
+	, mplayer_svn(-1) // Not found yet
 #if NOTIFY_SUB_CHANGES
-	qRegisterMetaType<SubTracks>("SubTracks");
+	, subtitle_info_received(false)
+	, subtitle_info_changed(false)
 #endif
-
 #if NOTIFY_AUDIO_CHANGES
-	qRegisterMetaType<Tracks>("Tracks");
+	, audio_info_changed(false)
 #endif
+	, dvd_current_title(-1)
+	, br_current_title(-1)
+{
+	player_id = PlayerID::MPLAYER;
 
 	connect( this, SIGNAL(lineAvailable(QByteArray)),
 			 this, SLOT(parseLine(QByteArray)) );
@@ -48,10 +56,6 @@ MplayerProcess::MplayerProcess(QObject * parent) : MyProcess(parent)
 
 	connect( this, SIGNAL(error(QProcess::ProcessError)),
              this, SLOT(gotError(QProcess::ProcessError)) );
-
-	notified_mplayer_is_running = false;
-	last_sub_id = -1;
-	mplayer_svn = -1; // Not found yet
 }
 
 MplayerProcess::~MplayerProcess() {
@@ -76,80 +80,13 @@ bool MplayerProcess::start() {
 #endif
 
 	dvd_current_title = -1;
+	br_current_title = -1;
 
 	MyProcess::start();
 
-#if !defined(Q_OS_OS2)
 	return waitForStarted();
-#else
-	bool r = waitForStarted();
-	if (r) {
-		pidMP = QProcess::pid();
-		qDebug("MPlayer PID %i", pidMP);
-		MPpipeOpen();
-	}
-	return r;
-#endif
 }
 
-void MplayerProcess::writeToStdin(QString text) {
-	if (isRunning()) {
-		//qDebug("MplayerProcess::writeToStdin");
-#if !defined(Q_OS_OS2)
-		#ifdef Q_OS_WIN
-		write( text.toUtf8() + "\n");
-		#else
-		write( text.toLocal8Bit() + "\n");
-		#endif
-#else
-		MPpipeWrite( text.toLocal8Bit() + "\n");
-#endif
-	} else {
-		qWarning("MplayerProcess::writeToStdin: process not running");
-	}
-#ifdef Q_OS_OS2
-	if (text == "quit" || text == "quit\n") {
-		MPpipeClose();
-	}
-#endif
-}
-
-#ifdef Q_OS_OS2
-void MplayerProcess::MPpipeOpen() {
-	char szPipeName[ 100 ];
-	sprintf( szPipeName, "\\PIPE\\MPLAYER\\%x", pidMP );
-	DosCreateNPipe( szPipeName, &hpipe, NP_ACCESS_DUPLEX, 1, 1024, 1024, 0 );
-}
-
-void MplayerProcess::MPpipeClose( void ) {
-	DosClose( hpipe );
-}
-
-void MplayerProcess::MPpipeWrite( const QByteArray text ) {
-	// MPlayer quitted ?
-	if ( !isRunning() )
-		return;
-
-// as things could hang when pipe communication is done direct here, i do a seperate thread for it
-	pipeThread = new PipeThread(text, hpipe);
-    
-	pipeThread->start();
-	while (!pipeThread->isRunning() && !pipeThread->isFinished()) {
-		qDebug("we sleep");
-		DosSleep(10);
-	}
-// we wait for max 2 seconds for the thread to be ended (we to this with max 20 loops)
-	int count = 0;
-	while (!pipeThread->wait(100) && count < 20) {
-		count ++;
-	}
-	if (count >= 20) {
-		pipeThread->terminate();
-		qDebug("pipe communication terminated");
-	}
-	delete pipeThread;
-}
-#endif
 
 static QRegExp rx_av("^[AV]: *([0-9,:.-]+)");
 static QRegExp rx_frame("^[AV]:.* (\\d+)\\/.\\d+");// [0-9,.]+");
@@ -158,7 +95,7 @@ static QRegExp rx("^(.*)=(.*)");
 static QRegExp rx_audio_mat("^ID_AID_(\\d+)_(LANG|NAME)=(.*)");
 #endif
 static QRegExp rx_video("^ID_VID_(\\d+)_(LANG|NAME)=(.*)");
-static QRegExp rx_title("^ID_DVD_TITLE_(\\d+)_(LENGTH|CHAPTERS|ANGLES)=(.*)");
+static QRegExp rx_title("^ID_(DVD|BLURAY)_TITLE_(\\d+)_(LENGTH|CHAPTERS|ANGLES)=(.*)");
 static QRegExp rx_chapters("^ID_CHAPTER_(\\d+)_(START|END|NAME)=(.+)");
 static QRegExp rx_winresolution("^VO: \\[(.*)\\] (\\d+)x(\\d+) => (\\d+)x(\\d+)");
 static QRegExp rx_ao("^AO: \\[(.*)\\]");
@@ -178,6 +115,7 @@ static QRegExp rx_mkvchapters("\\[mkv\\] Chapter (\\d+) from");
 static QRegExp rx_aspect2("^Movie-Aspect is ([0-9,.]+):1");
 static QRegExp rx_fontcache("^\\[ass\\] Updating font cache|^\\[ass\\] Init");
 static QRegExp rx_scanning_font("Scanning file");
+static QRegExp rx_forbidden("Server returned 403: Forbidden");
 #if DVDNAV_SUPPORT
 static QRegExp rx_dvdnav_switch_title("^DVDNAV, switched to title: (\\d+)");
 static QRegExp rx_dvdnav_length("^ANS_length=(.*)");
@@ -368,7 +306,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 #if !CHECK_VIDEO_CODEC_FOR_NO_VIDEO
 		// No video
 		if (rx_novideo.indexIn(line) > -1) {
-			md.novideo = TRUE;
+			md.novideo = true;
 			emit receivedNoVideo();
 			//emit mplayerFullyLoaded();
 		}
@@ -620,25 +558,25 @@ void MplayerProcess::parseLine(QByteArray ba) {
 		}
 		else
 
-		// DVD titles
+		// DVD/Bluray titles
 		if (rx_title.indexIn(line) > -1) {
-			int ID = rx_title.cap(1).toInt();
-			QString t = rx_title.cap(2);
+			int ID = rx_title.cap(2).toInt();
+			QString t = rx_title.cap(3);
 
 			if (t=="LENGTH") {
-				double length = rx_title.cap(3).toDouble();
+				double length = rx_title.cap(4).toDouble();
 				qDebug("MplayerProcess::parseLine: Title: ID: %d, Length: '%f'", ID, length);
 				md.titles.addDuration(ID, length);
 			} 
 			else
 			if (t=="CHAPTERS") {
-				int chapters = rx_title.cap(3).toInt();
+				int chapters = rx_title.cap(4).toInt();
 				qDebug("MplayerProcess::parseLine: Title: ID: %d, Chapters: '%d'", ID, chapters);
 				md.titles.addChapters(ID, chapters);
 			}
 			else
 			if (t=="ANGLES") {
-				int angles = rx_title.cap(3).toInt();
+				int angles = rx_title.cap(4).toInt();
 				qDebug("MplayerProcess::parseLine: Title: ID: %d, Angles: '%d'", ID, angles);
 				md.titles.addAngles(ID, angles);
 			}
@@ -772,6 +710,12 @@ void MplayerProcess::parseLine(QByteArray ba) {
 		}
 		else
 
+		if (rx_forbidden.indexIn(line) > -1) {
+			qDebug("MplayerProcess::parseLine: 403 forbidden");
+			emit receivedForbiddenText();
+		}
+		else
+
 		// Catch starting message
 		/*
 		pos = rx_play.indexIn(line);
@@ -806,6 +750,15 @@ void MplayerProcess::parseLine(QByteArray ba) {
 			if (tag == "ID_LENGTH") {
 				md.duration = value.toDouble();
 				qDebug("MplayerProcess::parseLine: md.duration set to %f", md.duration);
+				// Use the bluray title length if duration is 0
+				if (md.duration == 0 && br_current_title != -1) {
+					int i = md.titles.find(br_current_title);
+					if (i != -1) {
+						double duration = md.titles.itemAt(i).duration();
+						qDebug("MplayerProcess::parseLine: using the br title length: %f", duration);
+						md.duration = duration;
+					}
+				}
 			}
 			else
 			if (tag == "ID_VIDEO_WIDTH") {
@@ -886,6 +839,11 @@ void MplayerProcess::parseLine(QByteArray ba) {
 			if (tag == "ID_DVD_CURRENT_TITLE") {
 				dvd_current_title = value.toInt();
 			}
+			else
+			if (tag == "ID_BLURAY_CURRENT_TITLE") {
+				br_current_title = value.toInt();
+			}
+
 		}
 	}
 }
@@ -904,31 +862,5 @@ void MplayerProcess::gotError(QProcess::ProcessError error) {
 	qDebug("MplayerProcess::gotError: %d", (int) error);
 }
 
-#ifdef Q_OS_OS2
-PipeThread::PipeThread(const QByteArray t, const HPIPE pipe) {
-	text = t;
-	hpipe = pipe;
-}
-
-PipeThread::~PipeThread() {
-}
-
-void PipeThread::run() {
-	ULONG cbActual;
-	APIRET rc = NO_ERROR; 
-
-	rc = DosConnectNPipe( hpipe );
-	if (rc != NO_ERROR) 
-		return;
-
-//	qDebug("pipe connected");    
-	DosWrite( hpipe, text.data(), strlen( text.data() ), &cbActual );
-
-	// Wait for ACK
-	DosRead( hpipe, &cbActual, sizeof( ULONG ), &cbActual );
-	DosDisConnectNPipe( hpipe );
-	return;
-}
-#endif
-
+#include "mplayeroptions.cpp"
 #include "moc_mplayerprocess.cpp"
