@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,12 +24,14 @@
 #include "urlhistory.h"
 #include "filters.h"
 #include "autohidewidget.h"
+#include "helper.h"
 
 #include <QSettings>
 #include <QFileInfo>
 #include <QRegExp>
 #include <QDir>
 #include <QLocale>
+#include <QNetworkProxy>
 
 #if QT_VERSION >= 0x050000
 #include <QStandardPaths>
@@ -86,6 +88,9 @@ void Preferences::reset() {
 	ao = "";
 
 	use_screenshot = true;
+#ifdef MPV_SUPPORT
+	screenshot_template = "cap_%F_%p_%02n";
+#endif
 	screenshot_directory="";
 #ifdef PORTABLE_APP
 	screenshot_directory= "./screenshots";
@@ -132,7 +137,11 @@ void Preferences::reset() {
 	vdpau.disable_video_filters = true;
 #endif
 
+#ifdef Q_OS_WIN
+	use_soft_vol = false;
+#else
 	use_soft_vol = true;
+#endif
 	softvol_max = 110; // 110 = default value in mplayer
 	use_scaletempo = Detect;
 	use_hwac3 = false;
@@ -155,6 +164,8 @@ void Preferences::reset() {
 	min_step = 4;
 
 	osd = None;
+	osd_scale = 1;
+	subfont_osd_scale = 3;
 	osd_delay = 2200;
 
 	file_settings_method = "hash"; // Possible values: normal & hash
@@ -205,6 +216,7 @@ void Preferences::reset() {
 #endif
 
 	threads = 1;
+	hwdec = "no";
 
 	cache_for_files = 2048;
 	cache_for_streams = 2048;
@@ -214,29 +226,30 @@ void Preferences::reset() {
 	cache_for_tv = 3000;
 
 #ifdef YOUTUBE_SUPPORT
+	enable_yt_support = true;
 	yt_quality = RetrieveYoutubeUrl::MP4_720p;
 	//yt_user_agent = "Mozilla/5.0 (X11; Linux x86_64; rv:5.0.1) Gecko/20100101 Firefox/5.0.1";
 	yt_user_agent = "";
 	yt_use_https_main = false;
 	yt_use_https_vi = false;
 #endif
+#ifdef MPV_SUPPORT
+	enable_streaming_sites = false;
+#endif
 
 
     /* *********
        Subtitles
        ********* */
 
-	font_file = "";
-	font_name = "";
-	use_fontconfig = false;
 	subcp = "ISO-8859-1";
 	use_enca = false;
 	enca_lang = QString(QLocale::system().name()).section("_",0,0);
-	font_autoscale = 1;
 	subfuzziness = 1;
 	autoload_sub = true;
 
 	use_ass_subtitles = true;
+	enable_ass_styles = true;
 	ass_line_spacing = 0;
 
 	use_forced_subs_only = false;
@@ -245,7 +258,6 @@ void Preferences::reset() {
 
 	subtitles_on_screenshots = false;
 
-	use_new_sub_commands = Detect;
 	change_sub_scale_should_restart = Detect;
 
 	fast_load_sub = true;
@@ -328,6 +340,10 @@ void Preferences::reset() {
 
 	time_to_kill_mplayer = 1000;
 
+#ifdef MPRIS2
+	use_mpris2 = true;
+#endif
+
 
     /* *********
        GUI stuff
@@ -345,7 +361,7 @@ void Preferences::reset() {
 	style="";
 #endif
 
-	move_when_dragging = false;
+	move_when_dragging = true;
 
 
 #if DVDNAV_SUPPORT
@@ -403,13 +419,9 @@ void Preferences::reset() {
 
 	allow_video_movement = false;
 
-#ifdef SKINS
-	gui = "SkinGUI";
-	iconset = "Gonzo";
-#else
 	gui = "DefaultGUI";
-	iconset = "";
-#endif
+	iconset = "H2O";
+
 
 #if USE_MINIMUMSIZE
 	gui_minimum_width = 0; // 0 == disabled
@@ -444,6 +456,19 @@ void Preferences::reset() {
 	last_tv_channel = "";
 
 
+    /* ********
+       Network
+       ******** */
+
+	// Proxy
+	use_proxy = false;
+	proxy_type = QNetworkProxy::HttpProxy;
+	proxy_host = "";
+	proxy_port = 0;
+	proxy_username = "";
+	proxy_password = "";
+
+
     /* ***********
        Directories
        *********** */
@@ -560,6 +585,9 @@ void Preferences::save() {
 	set->setValue("driver/audio_output", ao);
 
 	set->setValue("use_screenshot", use_screenshot);
+	#ifdef MPV_SUPPORT
+	set->setValue("screenshot_template", screenshot_template);
+	#endif
 	#if QT_VERSION >= 0x040400
 	set->setValue("screenshot_folder", screenshot_directory);
 	#else
@@ -622,6 +650,8 @@ void Preferences::save() {
 	set->setValue("min_step", min_step);
 
 	set->setValue("osd", osd);
+	set->setValue("osd_scale", osd_scale);
+	set->setValue("subfont_osd_scale", subfont_osd_scale);
 	set->setValue("osd_delay", osd_delay);
 
 	set->setValue("file_settings_method", file_settings_method);
@@ -673,6 +703,7 @@ void Preferences::save() {
 #endif
 
 	set->setValue("threads", threads);
+	set->setValue("hwdec", hwdec);
 
 	set->setValue("cache_for_files", cache_for_files);
 	set->setValue("cache_for_streams", cache_for_streams);
@@ -685,6 +716,7 @@ void Preferences::save() {
 
 #ifdef YOUTUBE_SUPPORT
 	set->beginGroup("youtube");
+	set->setValue("enable_yt_support", enable_yt_support);
 	set->setValue("quality", yt_quality);
 	set->setValue("user_agent", yt_user_agent);
 	set->setValue("yt_use_https_main", yt_use_https_main);
@@ -692,6 +724,13 @@ void Preferences::save() {
 	set->endGroup();
 #endif
 
+#ifdef MPV_SUPPORT
+	set->beginGroup("streaming");
+	set->setValue("enable_streaming_sites", enable_streaming_sites);
+	set->endGroup();
+#endif
+
+
 
     /* *********
        Subtitles
@@ -699,18 +738,14 @@ void Preferences::save() {
 
 	set->beginGroup("subtitles");
 
-	set->setValue("font_file", font_file);
-	set->setValue("font_name", font_name);
-
-	set->setValue("use_fontconfig", use_fontconfig);
 	set->setValue("subcp", subcp);
 	set->setValue("use_enca", use_enca);
 	set->setValue("enca_lang", enca_lang);
-	set->setValue("font_autoscale", font_autoscale);
 	set->setValue("subfuzziness", subfuzziness);
 	set->setValue("autoload_sub", autoload_sub);
 
 	set->setValue("use_ass_subtitles", use_ass_subtitles);
+	set->setValue("enable_ass_styles", enable_ass_styles);
 	set->setValue("ass_line_spacing", ass_line_spacing);
 	set->setValue("use_forced_subs_only", use_forced_subs_only);
 
@@ -718,7 +753,6 @@ void Preferences::save() {
 
 	set->setValue("subtitles_on_screenshots", subtitles_on_screenshots);
 
-	set->setValue("use_new_sub_commands", use_new_sub_commands);
 	set->setValue("change_sub_scale_should_restart", change_sub_scale_should_restart);
 
 	set->setValue("fast_load_sub", fast_load_sub);
@@ -795,6 +829,10 @@ void Preferences::save() {
 
 	set->setValue("time_to_kill_mplayer", time_to_kill_mplayer);
 
+#ifdef MPRIS2
+	set->setValue("use_mpris2", use_mpris2);
+#endif
+
 	set->endGroup(); // advanced
 
 
@@ -903,6 +941,21 @@ void Preferences::save() {
 	set->setValue("last_tv_channel", last_tv_channel);
 	set->endGroup(); // tv
 
+
+    /* ********
+       Network
+       ******** */
+
+	set->beginGroup("proxy");
+	set->setValue("use_proxy", use_proxy);
+	set->setValue("type", proxy_type);
+	set->setValue("host", proxy_host);
+	set->setValue("port", proxy_port);
+	set->setValue("username", proxy_username);
+	set->setValue("password", proxy_password);
+	set->endGroup(); // proxy
+
+
     /* ***********
        Directories
        *********** */
@@ -1053,6 +1106,9 @@ void Preferences::load() {
 	ao = set->value("driver/audio_output", ao).toString();
 
 	use_screenshot = set->value("use_screenshot", use_screenshot).toBool();
+	#ifdef MPV_SUPPORT
+	screenshot_template = set->value("screenshot_template", screenshot_template).toString();
+	#endif
 	#if QT_VERSION >= 0x040400
 	screenshot_directory = set->value("screenshot_folder", screenshot_directory).toString();
 	setupScreenshotFolder();
@@ -1117,6 +1173,8 @@ void Preferences::load() {
 	min_step = set->value("min_step", min_step).toInt();
 
 	osd = set->value("osd", osd).toInt();
+	osd_scale = set->value("osd_scale", osd_scale).toDouble();
+	subfont_osd_scale = set->value("subfont_osd_scale", subfont_osd_scale).toDouble();
 	osd_delay = set->value("osd_delay", osd_delay).toInt();
 
 	file_settings_method = set->value("file_settings_method", file_settings_method).toString();
@@ -1168,6 +1226,7 @@ void Preferences::load() {
 #endif
 
 	threads = set->value("threads", threads).toInt();
+	hwdec = set->value("hwdec", hwdec).toString();
 
 	cache_for_files = set->value("cache_for_files", cache_for_files).toInt();
 	cache_for_streams = set->value("cache_for_streams", cache_for_streams).toInt();
@@ -1180,6 +1239,7 @@ void Preferences::load() {
 
 #ifdef YOUTUBE_SUPPORT
 	set->beginGroup("youtube");
+	enable_yt_support = set->value("enable_yt_support", enable_yt_support).toBool();
 	yt_quality = set->value("quality", yt_quality).toInt();
 	yt_user_agent = set->value("user_agent", yt_user_agent).toString();
 	yt_use_https_main = set->value("yt_use_https_main", yt_use_https_main).toBool();
@@ -1187,6 +1247,12 @@ void Preferences::load() {
 	set->endGroup();
 #endif
 
+#ifdef MPV_SUPPORT
+	set->beginGroup("streaming");
+	enable_streaming_sites = set->value("enable_streaming_sites", enable_streaming_sites).toBool();
+	set->endGroup();
+#endif
+
 
     /* *********
        Subtitles
@@ -1194,18 +1260,14 @@ void Preferences::load() {
 
 	set->beginGroup("subtitles");
 
-	font_file = set->value("font_file", font_file).toString();
-	font_name = set->value("font_name", font_name).toString();
-
-	use_fontconfig = set->value("use_fontconfig", use_fontconfig).toBool();
 	subcp = set->value("subcp", subcp).toString();
 	use_enca = set->value("use_enca", use_enca).toBool();
 	enca_lang = set->value("enca_lang", enca_lang).toString();
-	font_autoscale = set->value("font_autoscale", font_autoscale).toInt();
 	subfuzziness = set->value("subfuzziness", subfuzziness).toInt();
 	autoload_sub = set->value("autoload_sub", autoload_sub).toBool();
 
 	use_ass_subtitles = set->value("use_ass_subtitles", use_ass_subtitles).toBool();
+	enable_ass_styles = set->value("enable_ass_styles", enable_ass_styles).toBool();
 	ass_line_spacing = set->value("ass_line_spacing", ass_line_spacing).toInt();
 
 	use_forced_subs_only = set->value("use_forced_subs_only", use_forced_subs_only).toBool();
@@ -1214,7 +1276,6 @@ void Preferences::load() {
 
 	subtitles_on_screenshots = set->value("subtitles_on_screenshots", subtitles_on_screenshots).toBool();
 
-	use_new_sub_commands = (OptionState) set->value("use_new_sub_commands", use_new_sub_commands).toInt();
 	change_sub_scale_should_restart = (OptionState) set->value("change_sub_scale_should_restart", change_sub_scale_should_restart).toInt();
 
 	fast_load_sub = set->value("fast_load_sub", fast_load_sub).toBool();
@@ -1294,6 +1355,10 @@ void Preferences::load() {
 
 	time_to_kill_mplayer = set->value("time_to_kill_mplayer", time_to_kill_mplayer).toInt();
 
+#ifdef MPRIS2
+	use_mpris2 = set->value("use_mpris2", use_mpris2).toBool();
+#endif
+
 	set->endGroup(); // advanced
 
 
@@ -1406,6 +1471,20 @@ void Preferences::load() {
 	set->endGroup(); // tv
 
 
+    /* ********
+       Network
+       ******** */
+
+	set->beginGroup("proxy");
+	use_proxy = set->value("use_proxy", use_proxy).toBool();
+	proxy_type = set->value("type", proxy_type).toInt();
+	proxy_host = set->value("host", proxy_host).toString();
+	proxy_port = set->value("port", proxy_port).toInt();
+	proxy_username = set->value("username", proxy_username).toString();
+	proxy_password = set->value("password", proxy_password).toString();
+	set->endGroup(); // proxy
+
+
     /* ***********
        Directories
        *********** */
@@ -1516,8 +1595,8 @@ void Preferences::load() {
        SMPlayer info
        ********* */
 
-#ifdef CHECK_UPGRADED
 	set->beginGroup("smplayer");
+#ifdef CHECK_UPGRADED
 	smplayer_stable_version = set->value("stable_version", smplayer_stable_version).toString();
 	check_if_upgraded = set->value("check_if_upgraded", check_if_upgraded).toBool();
 #endif
@@ -1561,7 +1640,7 @@ void Preferences::load() {
 			time_to_kill_mplayer = 1000;
 
 			resize_method = Never;
-			move_when_dragging = false;
+			//move_when_dragging = false;
 		}
 		config_version = CURRENT_CONFIG_VERSION;
 	}
@@ -1569,21 +1648,47 @@ void Preferences::load() {
 #ifdef Q_OS_WIN
 	// Check if the mplayer binary exists and try to fix it
 	if (!QFile::exists(mplayer_bin)) {
-		qWarning("mplayer_bin '%s' doesn' exist", mplayer_bin.toLatin1().constData());
+		qWarning("mplayer_bin '%s' doesn't exist", mplayer_bin.toLatin1().constData());
 		bool fixed = false;
 		if (QFile::exists("mplayer/mplayer.exe")) {
 			mplayer_bin = "mplayer/mplayer.exe";
 			fixed = true;
-		} else
+		}
+		else
 		if (QFile::exists("mplayer/mplayer2.exe")) {
 			mplayer_bin = "mplayer/mplayer2.exe";
 			fixed = true;
 		}
+		else
+		if (QFile::exists("mplayer/mpv.exe")) {
+			mplayer_bin = "mplayer/mpv.exe";
+			fixed = true;
+		}
 		if (fixed) {
 			qWarning("mplayer_bin changed to '%s'", mplayer_bin.toLatin1().constData());
 		}
 	}
 #endif
+#ifdef Q_OS_LINUX
+	if (!QFile::exists(mplayer_bin)) {
+		QString app_path = Helper::findExecutable(mplayer_bin);
+		//qDebug("Preferences::load: app_path: %s", app_path.toUtf8().constData());
+		if (!app_path.isEmpty()) {
+			mplayer_bin = app_path;
+		} else {
+			// Executable not found, try to find an alternative
+			if (mplayer_bin.startsWith("mplayer")) {
+				app_path = Helper::findExecutable("mpv");
+				if (!app_path.isEmpty()) mplayer_bin = app_path;
+			}
+			else
+			if (mplayer_bin.startsWith("mpv")) {
+				app_path = Helper::findExecutable("mplayer");
+				if (!app_path.isEmpty()) mplayer_bin = app_path;
+			}
+		}
+	}
+#endif
 }
 
 #endif // NO_USE_INI_FILES
@@ -1628,7 +1733,7 @@ void Preferences::setupScreenshotFolder() {
 			qWarning("Preferences::setupScreenshotFolder: folder '%s' does not exist. Using /tmp as fallback", pdir.toUtf8().constData());
 			pdir = "/tmp";
 		}
-		QString default_screenshot_path = pdir + "/smplayer_screenshots";
+		QString default_screenshot_path = QDir::toNativeSeparators(pdir + "/smplayer_screenshots");
 		if (!QFile::exists(default_screenshot_path)) {
 			qDebug("Preferences::setupScreenshotFolder: creating '%s'", default_screenshot_path.toUtf8().constData());
 			if (!QDir().mkdir(default_screenshot_path)) {
@@ -1639,5 +1744,8 @@ void Preferences::setupScreenshotFolder() {
 			screenshot_directory = default_screenshot_path;
 		}
 	}
+	else {
+		screenshot_directory = QDir::toNativeSeparators(screenshot_directory);
+	}
 #endif
 }
