@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include "assstyles.h"
 
 #ifdef UPDATE_CHECKER
-#include "updatechecker.h"
+#include "updatecheckerdata.h"
 #endif
 
 class Recents;
@@ -79,6 +79,9 @@ public:
 	QString ao; // audio output
 
 	bool use_screenshot;
+#ifdef MPV_SUPPORT
+	QString screenshot_template;
+#endif
 	QString screenshot_directory;
 
 	// SMPlayer will remember all media settings for all videos.
@@ -148,6 +151,8 @@ public:
 
 	// Misc
 	int osd;
+	double osd_scale; // mpv
+	double subfont_osd_scale; // mplayer
 	int osd_delay; //<! Delay in ms to show the OSD.
 
 	QString file_settings_method; //!< Method to be used for saving file settings
@@ -191,6 +196,7 @@ public:
 #endif
 
 	int threads; //!< number of threads to use for decoding (-lavdopts threads <1-8>)
+	QString hwdec; //!< hardware video decoding (mpv only)
 
 	int cache_for_files;
 	int cache_for_streams;
@@ -200,8 +206,14 @@ public:
 	int cache_for_tv;
 
 #ifdef YOUTUBE_SUPPORT
+	bool enable_yt_support;
 	int yt_quality;
 	QString yt_user_agent;
+	bool yt_use_https_main;
+	bool yt_use_https_vi;
+#endif
+#ifdef MPV_SUPPORT
+	bool enable_streaming_sites;
 #endif
 
 
@@ -209,17 +221,14 @@ public:
 	   Subtitles
 	   ********* */
 
-	QString font_file;
-	QString font_name;
-	bool use_fontconfig;
 	QString subcp; // -subcp
 	bool use_enca;
 	QString enca_lang;
-	int font_autoscale; // -subfont-autoscale
 	int subfuzziness;
 	bool autoload_sub;
 
 	bool use_ass_subtitles;
+	bool enable_ass_styles;
 	int ass_line_spacing;
 
 	bool use_forced_subs_only;
@@ -228,9 +237,6 @@ public:
 
 	bool subtitles_on_screenshots;
 
-	//! Use the new sub_vob, sub_demux and sub_file commands
-	//! instead of sub_select
-	OptionState use_new_sub_commands; 
 	OptionState change_sub_scale_should_restart;
 
 	//! If true, loading an external subtitle will be done
@@ -321,6 +327,10 @@ public:
 
 	int time_to_kill_mplayer;
 
+#ifdef MPRIS2
+	bool use_mpris2;
+#endif
+
 
 	/* *********
 	   GUI stuff
@@ -392,6 +402,10 @@ public:
 	//! Close the main window when a file or playlist finish
 	bool close_on_finish;
 
+#ifdef AUTO_SHUTDOWN_PC
+	bool auto_shutdown_pc;
+#endif
+
 	QString default_font;
 
 	//!< Pause the current file when the main window is not visible
@@ -433,7 +447,20 @@ public:
 	int initial_tv_deinterlace;
 	QString last_dvb_channel;
 	QString last_tv_channel;
-	
+
+
+    /* ********
+       Network
+       ******** */
+
+	// Proxy
+	bool use_proxy;
+	int proxy_type;
+	QString proxy_host;
+	int proxy_port;
+	QString proxy_username;
+	QString proxy_password;
+
 
     /* ***********
        Directories
