@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include "mediasettings.h"
 #include "paths.h"
 #include "vdpauproperties.h"
+#include "playerid.h"
 
 #if USE_ALSA_DEVICES || USE_DSOUND_DEVICES
 #include "deviceinfo.h"
@@ -39,6 +40,7 @@ PrefGeneral::PrefGeneral(QWidget * parent, Qt::WindowFlags f)
 
 	// Read driver info from InfoReader:
 	InfoReader * i = InfoReader::obj();
+	i->getInfo();
 	vo_list = i->voList();
 	ao_list = i->aoList();
 
@@ -70,6 +72,15 @@ PrefGeneral::PrefGeneral(QWidget * parent, Qt::WindowFlags f)
 	vdpau_button->hide();
 #endif
 
+#ifndef AUTO_SHUTDOWN_PC
+	shutdown_widget->hide();
+#endif
+
+#ifndef MPV_SUPPORT
+	screenshot_template_label->hide();
+	screenshot_template_edit->hide();
+#endif
+
 	// Channels combo
 	channels_combo->addItem( "2", MediaSettings::ChStereo );
 	channels_combo->addItem( "4", MediaSettings::ChSurround );
@@ -148,6 +159,8 @@ void PrefGeneral::retranslateStrings() {
            "Example: <b>es|esp|spa</b> will select the track if it matches with "
             "<i>es</i>, <i>esp</i> or <i>spa</i>."));
 
+	executable_label->setText( tr("%1 &executable:").arg(PLAYER_NAME) );
+
 	createHelp();
 }
 
@@ -156,6 +169,9 @@ void PrefGeneral::setData(Preferences * pref) {
 
 	setUseScreenshots( pref->use_screenshot );
 	setScreenshotDir( pref->screenshot_directory );
+#ifdef MPV_SUPPORT
+	screenshot_template_edit->setText( pref->screenshot_template );
+#endif
 
 	QString vo = pref->vo;
 	if (vo.isEmpty()) {
@@ -198,6 +214,9 @@ void PrefGeneral::setData(Preferences * pref) {
 	setSubtitleTrack( pref->initial_subtitle_track );
 	setCloseOnFinish( pref->close_on_finish );
 	setPauseWhenHidden( pref->pause_when_hidden );
+#ifdef AUTO_SHUTDOWN_PC
+	shutdown_check->setChecked( pref->auto_shutdown_pc );
+#endif
 
 	setEq2( pref->use_soft_video_eq );
 	setUseAudioEqualizer( pref->use_audio_equalizer );
@@ -252,27 +271,28 @@ void PrefGeneral::getData(Preferences * pref) {
 
 		qDebug("PrefGeneral::getData: mplayer binary has changed, getting version number");
 		// Forces to get info from mplayer to update version number
-		InfoReader i( pref->mplayer_bin );
-		i.getInfo(); 
+		InfoReader * i = InfoReader::obj();
+		i->getInfo();
 		// Update the drivers list at the same time
-		//setDrivers( i.voList(), i.aoList() );
-#ifdef Q_OS_OS2
-		vo_list = i.voList();
-		ao_list = i.aoList();
+		vo_list = i->voList();
+		ao_list = i->aoList();
 		updateDriverCombos();
-#endif
 	}
 
 	TEST_AND_SET(pref->use_screenshot, useScreenshots());
 	TEST_AND_SET(pref->screenshot_directory, screenshotDir());
+#ifdef MPV_SUPPORT
+	TEST_AND_SET(pref->screenshot_template, screenshot_template_edit->text());
+#endif
+
 	TEST_AND_SET(pref->vo, VO());
-    TEST_AND_SET(pref->ao, AO());
+	TEST_AND_SET(pref->ao, AO());
 
 	bool dont_remember_ms = !rememberSettings();
     TEST_AND_SET(pref->dont_remember_media_settings, dont_remember_ms);
 
 	bool dont_remember_time = !rememberTimePos();
-    TEST_AND_SET(pref->dont_remember_time_pos, dont_remember_time);
+	TEST_AND_SET(pref->dont_remember_time_pos, dont_remember_time);
 
 	if (pref->file_settings_method != fileSettingsMethod()) {
 		pref->file_settings_method = fileSettingsMethod();
@@ -280,7 +300,7 @@ void PrefGeneral::getData(Preferences * pref) {
 	}
 
 	pref->audio_lang = audioLang();
-    pref->subtitle_lang = subtitleLang();
+	pref->subtitle_lang = subtitleLang();
 
 	pref->initial_audio_track = audioTrack();
 	pref->initial_subtitle_track = subtitleTrack();
@@ -288,6 +308,10 @@ void PrefGeneral::getData(Preferences * pref) {
 	pref->close_on_finish = closeOnFinish();
 	pref->pause_when_hidden = pauseWhenHidden();
 
+#ifdef AUTO_SHUTDOWN_PC
+	pref->auto_shutdown_pc = shutdown_check->isChecked();
+#endif
+
 	TEST_AND_SET(pref->use_soft_video_eq, eq2());
 	TEST_AND_SET(pref->use_soft_vol, softVol());
 	pref->global_volume = globalVolume();
@@ -335,12 +359,15 @@ void PrefGeneral::getData(Preferences * pref) {
 }
 
 void PrefGeneral::updateDriverCombos() {
-	int vo_current = vo_combo->currentIndex();
-	int ao_current = ao_combo->currentIndex();
+	QString current_vo = VO();
+	QString current_ao = AO();
 
 	vo_combo->clear();
 	ao_combo->clear();
 
+	vo_combo->addItem(tr("Default"), "player_default");
+	ao_combo->addItem(tr("Default"), "player_default");
+
 	QString vo;
 	for ( int n = 0; n < vo_list.count(); n++ ) {
 		vo = vo_list[n].name();
@@ -433,12 +460,12 @@ void PrefGeneral::updateDriverCombos() {
 	}
 	ao_combo->addItem( tr("User defined..."), "user_defined" );
 
-	vo_combo->setCurrentIndex( vo_current );
-	ao_combo->setCurrentIndex( ao_current );
+	setVO(current_vo);
+	setAO(current_ao);
 }
 
 void PrefGeneral::setMplayerPath( QString path ) {
-	mplayerbin_edit->setText( path );	
+	mplayerbin_edit->setText( path );
 }
 
 QString PrefGeneral::mplayerPath() {
@@ -864,11 +891,9 @@ void PrefGeneral::createHelp() {
 
 	addSectionTitle(tr("General"));
 
-	setWhatsThis(mplayerbin_edit, tr("MPlayer executable"), 
-		tr("Here you must specify the mplayer "
-           "executable that SMPlayer will use.<br>"
-           "SMPlayer requires at least MPlayer 1.0rc1 (although a recent "
-           "revision from SVN is highly recommended).") + "<br><b>" +
+	setWhatsThis(mplayerbin_edit, tr("%1 executable").arg(PLAYER_NAME),
+		tr("Here you must specify the %1 "
+           "executable that SMPlayer will use.").arg(PLAYER_NAME) + "<br><b>" +
         tr("If this setting is wrong, SMPlayer won't be able to play "
            "anything!") + "</b>");
 
@@ -900,15 +925,32 @@ void PrefGeneral::createHelp() {
            "SMPlayer will be stored. If the folder is not valid the "
            "screenshot feature will be disabled.") );
 
-	setWhatsThis(close_on_finish_check, tr("Close when finished"),
-		tr("If this option is checked, the main window will be automatically "
-		   "closed when the current file/playlist finishes.") );
+#ifdef MPV_SUPPORT
+	setWhatsThis(screenshot_template_edit, tr("Template for screenshots"),
+		tr("This option specifies the filename template used to save screenshots.") + " " +
+		tr("For example %1 would save the screenshot as 'moviename_0001.png'.").arg("%F_%04n") + "<br>" +
+		tr("%1 specifies the filename of the video without the extension, "
+		   "%2 adds a 4 digit number padded with zeros.").arg("%F").arg("%04n") + " " +
+		tr("For a full list of the template specifiers visit this link:") + 
+		" <a href=\"http://mpv.io/manual/stable/#options-screenshot-template\">"
+		"http://mpv.io/manual/stable/#options-screenshot-template</a>" + "<br>" +
+		tr("This option only works with mpv.") );
+#endif
 
 	setWhatsThis(pause_if_hidden_check, tr("Pause when minimized"),
 		tr("If this option is enabled, the file will be paused when the "
            "main window is hidden. When the window is restored, playback "
            "will be resumed.") );
 
+	setWhatsThis(close_on_finish_check, tr("Close when finished"),
+		tr("If this option is checked, the main window will be automatically "
+		   "closed when the current file/playlist finishes.") );
+
+#ifdef AUTO_SHUTDOWN_PC
+	setWhatsThis(shutdown_check, tr("Shut down computer"),
+		tr("If this option is enabled, the computer will shut down just after SMPlayer is closed.") );
+#endif
+
 	// Video tab
 	addSectionTitle(tr("Video"));
 
