@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -80,7 +80,7 @@ PrefInterface::PrefInterface(QWidget * parent, Qt::WindowFlags f)
 		QString css_file = Paths::themesPath() + "/" + iconsets[n] + "/main.css";
 		bool is_skin = QFile::exists(css_file);
 		//qDebug("***** %s %d", css_file.toUtf8().constData(), is_skin);
-		if ((is_skin) && (iconset_combo->findText( iconsets[n] ) == -1)) {
+		if ((is_skin) && (skin_combo->findText( iconsets[n] ) == -1)) {
 			skin_combo->addItem( iconsets[n] );
 			n_skins++;
 		}
@@ -177,15 +177,15 @@ void PrefInterface::retranslateStrings() {
 	seek4->setLabel( tr("Mouse &wheel jump") );
 
 	if (qApp->isLeftToRight()) {
-		seek1->setIcon( Images::icon("forward10s") );
-		seek2->setIcon( Images::icon("forward1m") );
-		seek3->setIcon( Images::icon("forward10m") );
+		seek1->setIcon( Images::icon("forward10s", 32) );
+		seek2->setIcon( Images::icon("forward1m", 32) );
+		seek3->setIcon( Images::icon("forward10m", 32) );
 	} else {
-		seek1->setIcon( Images::flippedIcon("forward10s") );
-		seek2->setIcon( Images::flippedIcon("forward1m") );
-		seek3->setIcon( Images::flippedIcon("forward10m") );
+		seek1->setIcon( Images::flippedIcon("forward10s", 32) );
+		seek2->setIcon( Images::flippedIcon("forward1m", 32) );
+		seek3->setIcon( Images::flippedIcon("forward10m", 32) );
 	}
-	seek4->setIcon( Images::icon("mouse", seek1->icon()->width()) );
+	seek4->setIcon( Images::icon("mouse",32) );
 
 	// Language combo
 	int language_item = language_combo->currentIndex();
