@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,6 +45,8 @@ signals:
 	//! Emitted with a few ms of delay
 	void delayedDraggingPos(int);
 #endif
+	void wheelUp();
+	void wheelDown();
 
 protected slots:
 	void stopUpdate();
@@ -56,7 +58,7 @@ protected slots:
 	void sendDelayedPos();
 #endif
 
-	/* virtual void wheelEvent( QWheelEvent * e ); */
+	virtual void wheelEvent(QWheelEvent * e);
 
 private:
 	bool dont_update;
