@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -117,6 +117,9 @@ QWidget * TimeSliderAction::createWidget ( QWidget * parent ) {
 	         this, SIGNAL(delayedDraggingPos(int)) );
 #endif
 
+	connect(t, SIGNAL(wheelUp()), this, SIGNAL(wheelUp()));
+	connect(t, SIGNAL(wheelDown()), this, SIGNAL(wheelDown()));
+
 	return t;
 }
 
